@@ -4,12 +4,12 @@ from click.testing import CliRunner
 
 EXPECTED_OUTPUT = """
 polygon
-├── mainnet
-│   └── geth  (default)
-├── mumbai
-│   └── geth  (default)
-└── local  (default)
-    └── test  (default)
+├── amoy
+│   └── node  (default)
+├── local  (default)
+│   └── test  (default)
+└── mainnet
+    └── node  (default)
 """.strip()
 
 
@@ -46,8 +46,8 @@ def assert_rich_text(actual: str, expected: str):
 
 def test_networks(runner, cli, polygon):
     # Do this in case local env changed it.
-    polygon.mainnet.set_default_provider("geth")
-    polygon.mumbai.set_default_provider("geth")
+    polygon.mainnet.set_default_provider("node")
+    polygon.amoy.set_default_provider("node")
 
-    result = runner.invoke(cli, ["networks", "list"])
+    result = runner.invoke(cli, ("networks", "list"))
     assert_rich_text(result.output, EXPECTED_OUTPUT)
